[![PyPI Version](https://badge.fury.io/py/ucdp-glbl.svg)](https://badge.fury.io/py/ucdp-glbl)
[![Python Build](https://github.com/nbiotcloud/ucdp-glbl/actions/workflows/main.yml/badge.svg)](https://github.com/nbiotcloud/ucdp-glbl/actions/workflows/main.yml)
[![Documentation](https://readthedocs.org/projects/ucdp-glbl/badge/?version=stable)](https://ucdp-glbl.readthedocs.io/en/stable/?badge=stable)
[![Coverage Status](https://coveralls.io/repos/github/nbiotcloud/ucdp-glbl/badge.svg?branch=main)](https://coveralls.io/github/nbiotcloud/ucdp-glbl?branch=main)
[![python-versions](https://img.shields.io/pypi/pyversions/ucdp-glbl.svg)](https://pypi.python.org/pypi/ucdp-glbl)

# Unified Chip Design Platform - Global

* [Documentation](https://ucdp-glbl.readthedocs.io/en/stable/)
* [PyPI](https://pypi.org/project/ucdp-glbl/)
* [Sources](https://github.com/nbiotcloud/ucdp-glbl)
* [Issues](https://github.com/nbiotcloud/ucdp-glbl/issues)

## Installation

Installing it is pretty easy:

```bash
pip install ucdp-glbl
```
